export P=libwebp
export V=1.0.2
export B=1
export MAINTAINER=JuergenFischer

savelog() {
	local f=$1
	rm -f $f.9
	for i in $(seq 8 -1 0); do [ -f "$f.$i" ] && mv $f.$i $f.$(( i + 1 )); done
	[ -f $f ] && mv $f $f.0
}

savelog package.log
exec > >(tee package.log) 2>&1
date

set -e

[ -f $P-$V.tar.gz ] || wget https://storage.googleapis.com/downloads.webmproject.org/releases/webp/$P-$V.tar.gz
[ -f ../CMakeLists.txt ] || tar -C .. --xform s,$P-$V/,, -xzf $P-$V.tar.gz

if ! [ -d "$OSGEO4W_REP" ]; then
        echo no repository
        exit 1
fi

fetchenv() {
        local IFS
        IFS=
        batch=$1
        shift

        if ! [ -f "$batch" ]; then
                echo "$batch not found"
                return 1
        fi

        srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
        dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
        diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
        envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
        cmd /c set >$srcenv
        cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
        /usr/bin/cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
        s/\\\\/\\//g;
        s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
        s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
        /usr/bin/diff -u $srcenv $dstenv | /usr/bin/sed -f $envdiff >$diffenv
        . $diffenv
        PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
        rm -f $srcenv $dstenv $diffenv $envdiff
}

for ARCH in ${ARCHS:-x86 x86_64}; do
	export ARCH

	(
		case "$ARCH" in
		x86)
			export OSGEO4W_ROOT=/c/OSGeo4W
			export CMAKE_GEN="Visual Studio 14 2015"
			export VCARCH=x86
			;;

		x86_64)
			export OSGEO4W_ROOT=/c/OSGeo4W64
			export VCARCH=x64
			export CMAKE_GEN="Visual Studio 14 2015 Win64"
			;;

		*)
			echo "Unsupported arch $ARCH" >&2
			exit 1
			;;
		esac

		export R=$OSGEO4W_REP/$ARCH/release/$P
		mkdir -p $R

		cat <<EOF >$R/setup.hint
sdesc: "WebP is a modern image format that provides superior lossless and lossy compression."
ldesc: "WebP is a modern image format that provides superior lossless and lossy compression."
maintainer: $MAINTAINER
category: Libs
requires: msvcrt2015 libtiff zlib libpng-vc14 libjpeg
EOF

		cp ../COPYING $R/$P-$V-$B.txt

		fetchenv $OSGEO4W_ROOT/bin/o4w_env.bat
		fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" $VCARCH

		export PATH="/c/Program Files (x86)/Microsoft Visual Studio 14.0/Common7/IDE:/c/Program Files/CMake/bin:$PATH:/bin"
		export INSTDIR=$PWD/install-$ARCH
		export BUILDCONF=RelWithDebInfo

		rm -rf $INSTDIR

		mkdir -p build-$ARCH
		cd build-$ARCH

		cmake -G "$CMAKE_GEN" \
			-DCMAKE_INSTALL_PREFIX=$(cygpath -m $INSTDIR) \
			-DPNG_LIBRARY=$(cygpath -w $OSGEO4W_ROOT/libs/vc14/lib/libpng16.lib) \
			-DPNG_PNG_INCLUDE_DIR=$(cygpath -w $OSGEO4W_ROOT/libs/vc14/include) \
			-DJPEG_LIBRARY_RELEASE=$(cygpath -w $OSGEO4W_ROOT/lib/jpeg_i.lib) \
			-DTIFF_LIBRARY_RELEASE=$(cygpath -w $OSGEO4W_ROOT/lib/libtiff_i.lib) \
			../..

		for i in ZERO_CHECK ALL_BUILD INSTALL; do
			echo "$i: $(date)"
			cmake --build . --target $i --config $BUILDCONF
		done

		/bin/tar -C $INSTDIR -cjf $R/$P-$V-$B.tar.bz2 \
			bin include lib share
		
		/bin/tar -C ../.. -cjf $R/$P-$V-$B-src.tar.bz2 \
			osgeo4w/package.sh
	)
done
